==> kbib-0.6.1.tar.gz: kbib-0.6.1/kbib/kbibcheckkeydlg.h <==
/***************************************************************************
                          kbibcheckkeydlg.h  -  description
                             -------------------
    begin                : Sat Jul 5 2003
    copyright            : (C) 2003 by Thach Nguyen
    email                : thach@dragon.thach.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KBIBCHECKKEYDLG_H
#define KBIBCHECKKEYDLG_H

#include <qwidget.h>
#include <kdialogbase.h>
#include <qlabel.h>

/**
  *@author Thach Nguyen
  */

class KBibCheckKeyDlg : public KDialogBase  {
   Q_OBJECT
public: 
	KBibCheckKeyDlg(QString msg=0, QWidget *parent=0, const char *name=0,  WFlags f=0);
	~KBibCheckKeyDlg();
  /** No descriptions */
  int getUserCode();
private: // Private attributes
  /**  */
  QLabel* msgLabel;
  /**  */
  int userCode;
public slots: // Public slots
  /** No descriptions */
  void slotUser3();
  /** No descriptions */
  /** No descriptions */
  void slotUser1();
  /** No descriptions */
  void slotUser2();
  void slotCancel();
};

#endif

==> kbib_0.6.5.orig.tar.gz: kbib-0.6.5/kbib/kbibcheckkeydlg.h <==
/***************************************************************************
                          kbibcheckkeydlg.h  -  description
                             -------------------
    begin                : Sat Jul 5 2003
    copyright            : (C) 2003 by Thach Nguyen
    email                : thach.nguyen@rmit.edu.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KBIBCHECKKEYDLG_H
#define KBIBCHECKKEYDLG_H

#include <qwidget.h>
#include <kdialogbase.h>
#include <qlabel.h>

/**
  *@author Thach Nguyen
  */

class KBibCheckKeyDlg : public KDialogBase  {
   Q_OBJECT
public: 
	KBibCheckKeyDlg(QString msg=0, QWidget *parent=0, const char *name=0,  WFlags f=0);
	~KBibCheckKeyDlg();
  /** No descriptions */
  int getUserCode();
private: // Private attributes
  /**  */
  QLabel* msgLabel;
  /**  */
  int userCode;
public slots: // Public slots
  /** No descriptions */
  void slotUser3();
  /** No descriptions */
  /** No descriptions */
  void slotUser1();
  /** No descriptions */
  void slotUser2();
  void slotCancel();
};

#endif
